==> google_applovin_unity_ads-1.0.9.tar.gz: lib/google_applovin_unity_ads.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'banner/banner_ad_widget.dart';
import 'banner/controller.dart';
import 'native/controller.dart';
import 'native/native_ad_widget.dart';

class GoogleApplovinUnityAds {
  static const channelName = 'dev.bitcoding.ads/google_applovin_unity_ads';
  static const platform = MethodChannel(channelName);

  static initialize(String json_data, {Function? callback = null}) async {
    GoogleApplovinUnityAds.platform.setMethodCallHandler(null);
    GoogleApplovinUnityAds.platform.setMethodCallHandler(
            (call) => handleIntraChannelCallback(call, callback: callback));

    await GoogleApplovinUnityAds.platform
        .invokeMethod('call.ads.api.setting', {"json_data": json_data});
  }

  static showIntraAds({Function? callback = null}) async {
    GoogleApplovinUnityAds.platform.setMethodCallHandler(null);
    GoogleApplovinUnityAds.platform.setMethodCallHandler(
        (call) => handleIntraChannelCallback(call, callback: callback));
    await GoogleApplovinUnityAds.platform.invokeMethod('call.ads.interestial');
  }

  static showOpenAds({Function? callback = null}) async {
    GoogleApplovinUnityAds.platform.setMethodCallHandler(null);
    GoogleApplovinUnityAds.platform.setMethodCallHandler(
            (call) => handleIntraChannelCallback(call, callback: callback));

    await GoogleApplovinUnityAds.platform.invokeMethod('call.ads.openad');
  }

  static Future<void> showRewardAds({Function? callback = null}) async {
    GoogleApplovinUnityAds.platform.setMethodCallHandler(null);
    GoogleApplovinUnityAds.platform.setMethodCallHandler((call) =>
        handleRewardChannelCallback(call, callback));
    await GoogleApplovinUnityAds.platform.invokeMethod('call.ads.rewarded');
  }

  static Future<void> handleIntraChannelCallback(MethodCall call,
      {Function? callback}) async {
    switch (call.method) {
      case 'SUCCESS':
        if (callback != null) {
          callback();
        }
        break;
      case 'ERROR':
        if (callback != null) {
          callback();
        }
        break;
    }
    // GoogleApplovinUnityAds.platform.setMethodCallHandler(null);
  }

  static Future<void> handleRewardChannelCallback(MethodCall call, Function? callback) async {
    switch (call.method) {
      case 'SUCCESS':
        if (callback != null) {
          callback();
        }
        break;
      case 'ERROR':
        Future.delayed(const Duration(milliseconds: 50), () {
          showIntraAds(callback: callback);
        });
        break;
    }
    // GoogleApplovinUnityAds.platform.setMethodCallHandler(null);
  }

  static bannerAds(
      {BannerSize bannerSize = BannerSize.BANNER,
      String adLoadingText = "Ad is loading.......",
      Color? boxDecorationcolor = const Color(0xFFFFFFFF),
        Color boxBordercolor = const Color(0xFFFFFFFF),
        TextStyle? style = const TextStyle(fontSize: 16, color: Colors.black),
        Widget? error = const SizedBox(
          height: 0,
        )}) {
    return Stack(
      children: [
        Container(
          decoration: BoxDecoration(
              color: boxDecorationcolor,
              border: Border.all(color: boxBordercolor)),
          height: bannerSize.size.height,
          child: Center(
            child: BannerAd(
              builder: (context, child) {
                return Container(
                  color: Colors.black,
                  child: child,
                );
              },
              loading: SizedBox(
                  height: bannerSize.size.height,
                  child: Center(
                      child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          crossAxisAlignment: CrossAxisAlignment.center,
                          children: [
                        Transform.scale(
                          scale: 0.5,
                          child: const CircularProgressIndicator(
                              color: Colors.black),
                        ),
                        SizedBox(
                          width: 7,
                        ),
                        Text(adLoadingText,
                            style: style)
                      ]))),
              // ignore: deprecated_member_use
              size: bannerSize,
            ),
          ),
        )
      ],
    );
  }

  static nativeAds(NativeSize nativeSize, String nativeSizeType, {
      String adLoadingText = "Ad is loading.......",
      Color? boxDecorationcolor = const Color(0xFFFFFFFF),
      Color boxBordercolor = const Color(0xFFFFFFFF),
      String button_background_color = "#000000",
      String button_text_color = "#FFFFFF",
      TextStyle? style = const TextStyle(fontSize: 16, color: Colors.black),
      Widget? error = const SizedBox(height: 0,)
      }) {
    return Container(
      height: nativeSize.size.height,
      alignment: Alignment.center,
      margin: EdgeInsets.only(left: 2, right: 2),
      decoration: BoxDecoration(
          color: boxDecorationcolor, border: Border.all(color: boxBordercolor)),
      child: Padding(
        padding: EdgeInsets.all(1),
        child: Center(
          child: NativeAd(
            action_button_background_color: button_background_color,
            action_button_text_color: button_text_color,
            nativeSizeType: nativeSizeType,
            builder: (context, child) {
              return Container(
                alignment: Alignment.center,
                color: Colors.black,
                child: child,
              );
            },
            loading: SizedBox(
                height: nativeSize.size.height,
                child: Center(
                    child: Row(
                        mainAxisAlignment: MainAxisAlignment.center,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                      Transform.scale(
                        scale: 0.5,
                        child: const CircularProgressIndicator(
                            color: Colors.black),
                      ),
                      SizedBox(
                        width: 8,
                      ),
                      Text(adLoadingText,
                          style: style)
                    ]))),
            size: nativeSize,
            error: error,
          ),
        ),
      ),
    );
  }
}

==> google_applovin_unity_ads-1.1.1.tar.gz: lib/google_applovin_unity_ads.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:google_applovin_unity_ads/interestial/admob_events.dart';
import 'package:google_applovin_unity_ads/interestial/interstitial_ad.dart';
import 'banner/banner_ad_widget.dart';
import 'banner/controller.dart';
import 'native/controller.dart';
import 'native/native_ad_widget.dart';

class GoogleApplovinUnityAds {
  static const channelName = 'dev.bitcoding.ads/google_applovin_unity_ads';
  static const platform = MethodChannel(channelName);

  static initialize(String json_data, {Function? callback = null}) async {
    GoogleApplovinUnityAds.platform.setMethodCallHandler(
            (call) => handleIntraChannelCallback(call, callback: callback));

    await GoogleApplovinUnityAds.platform
        .invokeMethod('call.ads.api.setting', {"json_data": json_data});
  }

  static showIntraAds({Function? callback = null}) async {
    /*GoogleApplovinUnityAds.platform.setMethodCallHandler(
        (call) => handleIntraChannelCallback(call, callback: callback));
    await GoogleApplovinUnityAds.platform.invokeMethod('call.ads.interestial');*/

  }

  static showOpenAds({Function? callback = null}) async {
    GoogleApplovinUnityAds.platform.setMethodCallHandler(
            (call) => handleIntraChannelCallback(call, callback: callback));

    await GoogleApplovinUnityAds.platform.invokeMethod('call.ads.openad');
  }

  static Future<void> showRewardAds({Function? callback = null}) async {
    GoogleApplovinUnityAds.platform.setMethodCallHandler((call) =>
        handleRewardChannelCallback(call, callback));
    await GoogleApplovinUnityAds.platform.invokeMethod('call.ads.rewarded');
  }

  static Future<void> handleIntraChannelCallback(MethodCall call,
      {Function? callback}) async {
    switch (call.method) {
      case 'SUCCESS':
        if (callback != null) {
          callback();
        }
        break;
      case 'ERROR':
        if (callback != null) {
          callback();
        }
        break;
    }
    // GoogleApplovinUnityAds.platform.setMethodCallHandler(null);
  }

  static Future<void> handleRewardChannelCallback(MethodCall call, Function? callback) async {
    switch (call.method) {
      case 'SUCCESS':
        if (callback != null) {
          callback();
        }
        break;
      case 'ERROR':
        Future.delayed(const Duration(milliseconds: 50), () {
          //showIntraAds(callback: callback);
        });
        break;
    }
    // GoogleApplovinUnityAds.platform.setMethodCallHandler(null);
  }

  static handleEvent(
      AdmobAdEvent event, {Function? callback = null}) {
    switch (event) {
      case AdmobAdEvent.success:
      case AdmobAdEvent.error:
        if (callback != null) {
          callback();
        }
       print('New Event Callback $event Ad loaded!');
        break;
      default:
        break;
    }
  }

  static bannerAds(
      {BannerSize bannerSize = BannerSize.BANNER,
      String adLoadingText = "Ad is loading.......",
      Color? boxDecorationcolor = const Color(0xFFFFFFFF),
        Color boxBordercolor = const Color(0xFFFFFFFF),
        TextStyle? style = const TextStyle(fontSize: 16, color: Colors.black),
        Widget? error = const SizedBox(
          height: 0,
        )}) {
    return Stack(
      children: [
        Container(
          decoration: BoxDecoration(
              color: boxDecorationcolor,
              border: Border.all(color: boxBordercolor)),
          height: bannerSize.size.height,
          child: Center(
            child: BannerAd(
              builder: (context, child) {
                return Container(
                  color: Colors.black,
                  child: child,
                );
              },
              loading: SizedBox(
                  height: bannerSize.size.height,
                  child: Center(
                      child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          crossAxisAlignment: CrossAxisAlignment.center,
                          children: [
                        Transform.scale(
                          scale: 0.5,
                          child: const CircularProgressIndicator(
                              color: Colors.black),
                        ),
                        SizedBox(
                          width: 7,
                        ),
                        Text(adLoadingText,
                            style: style)
                      ]))),
              // ignore: deprecated_member_use
              size: bannerSize,
            ),
          ),
        )
      ],
    );
  }

  static nativeAds(NativeSize nativeSize, String nativeSizeType, {
      String adLoadingText = "Ad is loading.......",
      Color? boxDecorationcolor = const Color(0xFFFFFFFF),
      Color boxBordercolor = const Color(0xFFFFFFFF),
      String button_background_color = "#000000",
      String button_text_color = "#FFFFFF",
      TextStyle? style = const TextStyle(fontSize: 16, color: Colors.black),
      Widget? error = const SizedBox(height: 0,)
      }) {
    return Container(
      height: nativeSize.size.height,
      alignment: Alignment.center,
      margin: EdgeInsets.only(left: 2, right: 2),
      decoration: BoxDecoration(
          color: boxDecorationcolor, border: Border.all(color: boxBordercolor)),
      child: Padding(
        padding: EdgeInsets.all(1),
        child: Center(
          child: NativeAd(
            action_button_background_color: button_background_color,
            action_button_text_color: button_text_color,
            nativeSizeType: nativeSizeType,
            builder: (context, child) {
              return Container(
                alignment: Alignment.center,
                color: Colors.black,
                child: child,
              );
            },
            loading: SizedBox(
                height: nativeSize.size.height,
                child: Center(
                    child: Row(
                        mainAxisAlignment: MainAxisAlignment.center,
                        crossAxisAlignment: CrossAxisAlignment.center,
                        children: [
                      Transform.scale(
                        scale: 0.5,
                        child: const CircularProgressIndicator(
                            color: Colors.black),
                      ),
                      SizedBox(
                        width: 8,
                      ),
                      Text(adLoadingText,
                          style: style)
                    ]))),
            size: nativeSize,
            error: error,
          ),
        ),
      ),
    );
  }
}
